@@ -214,8 +214,8 @@ class MethodCall:
         xmlstr+= "</methodCall>"
         return xmlstr.encode('utf-8')
     
-    def execute(self, gateway):
-        response = gateway.executeCommand(self)
+    async def execute(self, gateway):
+        response = await gateway.executeCommand(self)
         if response != None and isinstance(response, MethodResponse):
             self.process_response(response)
     
